#
# spec file for package python3-xonsh
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-xonsh
Version:        0.5.8
Release:        1.14
Summary:        A general purpose, Python-ish shell
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            https://xonsh.org
Source:         https://files.pythonhosted.org/packages/source/x/xonsh/xonsh-0.5.8.tar.gz
BuildRequires:  python3-Pygments
BuildRequires:  python3-coverage
BuildRequires:  python3-devel
BuildRequires:  python3-ply
BuildRequires:  python3-prompt_toolkit
BuildRequires:  python3-pytest
BuildRequires:  python3-setuptools
Requires:       python3-ply
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

# TODO: docs and contrib subpackage

%description
xonsh is a Python-ish, BASHwards-looking shell language and command prompt. The language is a superset of Python 3.4+ with additional shell primitives. xonsh (pronounced conch) is meant for the daily use of experts and novices alike.

%prep
%setup -q -n xonsh-%{version}
sed -i "1d" xonsh/xoreutils/_which.py
rm xonsh/dev.githash

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root,-)
%{python3_sitelib}/*
%{_bindir}/xonsh
%{_bindir}/xon.sh
%doc README.rst

%changelog
* Thu Mar  9 2017 sebix+novell.com@sebix.at
- version 0.5.8
* Wed Feb  1 2017 sebix+novell.com@sebix.at
- version 0.5.3
- Added:
  * Tab completion xontrib for python applications based on click framework.
  * Added on_transform_command event for pre-processing that macros can't handle.
  * Autodetection of backgroundability by binary analysis on POSIX.
  * New argument expand_user=True to tools.expand_path.
  * New $COMPLETION_QUERY_LIMIT environment variable for setting the number of completions above which the user will be asked if they wish to see the potential completions.
  * Users may now redirect stdout to stderr in subprocess mode.
- Changed:
  * The Block and Functor context managers from xonsh.contexts have been rewritten to use xonsh's macro capabilities. You must now enter these via the with! statement, e.g. with! Block(): pass.
  * The distributed xontrib now needs to use the with! statement, since it relies on Functor.
  * telnet has been flagged as unthreadable.
  * When $DYNAMIC_CWD_ELISION_CHAR is non empty and the last dir of cwd is too long and shortened, the elision char is added at the end.
  * pygments is no longer a strict dependency of the prompt_toolkit backend. If pygments is not installed, the PTK backend will use the default ansi color settings from the terminal. Syntax highlighting requires that pygments is installed.
  * Events are now keyword arguments only
  * Restored on_precommand to its original signature.
  * Move built_ins.expand_path to tools.expand_path.
  * Rename tools.expandpath to tools._expandpath.
  * Added gvim command to unthreadable predictors.
  * The source alias now passes $ARGS down to file it is sourcing.
- Removed:
  * XonshBlockError has been removed, since it no longer serves a purpose.
- Fixed:
  * PopenThread will now re-issue SIGINT to the main thread when it is recieved.
  * Fixed an issue that using sqlite history backend does not kill unfinished jobs when quitting xonsh with a second "exit".
  * Fixed an issue that xonsh would fail over to external shells when running .xsh script which raises exceptions.
  * Fixed an issue with openpty() returning non-unix line endings in its buffer. This was causing git and ssh to fail when xonsh was used as the login shell on the server. See https://mail.python.org/pipermail/python-list/2013-June/650460.html for more details.
  * Restored the ability to ^Z and fg processes on posix platforms.
  * CommandPipelines were not gauranteeded to have been ended when the return code was requested. This has been fixed.
  * Introduce path expansion in is_writable_file to fix $XONSH_TRACEBACK_LOGFILE=~/xonsh.log.
  * Backgrounding a running process (^Z) now restores ECHO mode to the terminal in cases where the subprocess doesn't properly restore itself. A major instance of this behaviour is Python's interactive interpreter.
  * Readline backend would not ask the user to confirm the printing of completion options if they numbered above a certain value. Instead they would be dumped to the screen. This has been fixed.
  * Jupyter kernel was no longer properly running subprocess commands. This has been fixed.
  * The filename is applied to the target of the source alias, providing better tracebacks.
* Thu Jan  5 2017 sebix+novell.com@sebix.at
- version 0.5.2
- Added:
  * Added weechat to default predictors
  * $DYNAMIC_CWD_ELISION_CHAR environment variable to control how a shortened path is displayed.
- Changed:
  * _ret_code function of prompt_ret_code xontrib return now None when return code is 0 instead of empty string allowing more customization of prompt format.
- Fixed:
  * Minor Python completer token counting bug fix.
  * multiline syntax error in PTK shell due to buffer not being reset
  * Segfaults and other early exit signals are now reported correctly, again.
* Wed Dec 21 2016 sebix+novell.com@sebix.at
- update to 0.5.1
* Sun Dec 18 2016 sebix+novell.com@sebix.at
- update to 0.4.7
- fix license
* Sat Aug 27 2016 sebix+novell.com@sebix.at
- initial package for xonsh
